ui

package
v0.4.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 26, 2026 License: MIT Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the main TUI model.

func NewModel

func NewModel(result scanner.ScanResult, projectRoot string, opts ...Options) Model

NewModel creates the initial model from scan results.

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() string

type Options added in v0.4.1

type Options struct {
	DismissDialog   bool          // send key events to dismiss compatibility dialog after launch
	ScreenshotDelay time.Duration // wait time before capturing screenshot (default 3s)
}

Options configures optional TUI behavior.

Directories

Path Synopsis
Package imgrender renders images in terminal cells.
Package imgrender renders images in terminal cells.
Package screenshot manages a disk-backed cache of device screenshots keyed by composable FQN.
Package screenshot manages a disk-backed cache of device screenshots keyed by composable FQN.

Jump to